@@ -926,6 +926,8 @@ class Reaction(Object):
             state["_upper_bound"] = state.pop("upper_bound")
 
         # Used for efficient storage in newer cobrapy versions
+        if "_gpr" not in state:
+            state["_gpr"] = state["_gene_reaction_rule"]
         if type(state["_gpr"]) is str:
             state["_gpr"] = GPR.from_string(state["_gpr"])
 
@@ -1228,7 +1230,6 @@ class Reaction(Object):
         _id_to_metabolites = dict([(x.id, x) for x in self._metabolites])
 
         for metabolite, coefficient in metabolites_to_add.items():
-
             # Make sure metabolites being added belong to the same model, or
             # else copy them.
             if isinstance(metabolite, Metabolite):
