@@ -614,9 +614,9 @@ def _sbml_to_model(
                 {
                     "familyName": c.getFamilyName() if c.isSetFamilyName() else None,
                     "givenName": c.getGivenName() if c.isSetGivenName() else None,
-                    "organisation": c.getOrganisation()
-                    if c.isSetOrganisation()
-                    else None,
+                    "organisation": (
+                        c.getOrganisation() if c.isSetOrganisation() else None
+                    ),
                     "email": c.getEmail() if c.isSetEmail() else None,
                 }
             )
@@ -1080,7 +1080,7 @@ def _sbml_to_model(
                     if f_replace and F_REACTION in f_replace:
                         obj_id = f_replace[F_REACTION](obj_id)
                     cobra_member = cobra_model.reactions.get_by_id(obj_id)
-                    cobra_member.subsystem = group.name
+                    cobra_member.subsystem = group.getName()
                 elif typecode == libsbml.SBML_FBC_GENEPRODUCT:
                     if f_replace and F_GENE in f_replace:
                         obj_id = f_replace[F_GENE](obj_id)
