@@ -50,11 +50,11 @@ logger = logging.getLogger(__name__)
 solvers = {
     match.split("_interface")[0]: getattr(optlang, match)
     for match in dir(optlang)
-    if "_interface" in match
+    if "_interface" in match and match != "matrix_interface"
 }
 
 # Defines all the QP solvers implemented in optlang.
-qp_solvers = ["cplex", "gurobi", "osqp"]
+qp_solvers = ["cplex", "gurobi", "hybrid"]
 
 # optlang solution statuses which still allow retrieving primal values
 has_primals = [NUMERIC, FEASIBLE, INFEASIBLE, SUBOPTIMAL, ITERATION_LIMIT, TIME_LIMIT]
@@ -252,9 +252,9 @@ def get_solver_name(mip: bool = False, qp: bool = False) -> str:
     if len(solvers) == 0:
         raise SolverNotFound("No solvers found.")
     # Those lists need to be updated as optlang implements more solvers
-    mip_order = ["gurobi", "cplex", "glpk"]
-    lp_order = ["glpk", "cplex", "gurobi"]
-    qp_order = ["gurobi", "cplex", "osqp"]
+    mip_order = ["gurobi", "cplex", "hybrid", "glpk"]
+    lp_order = ["glpk", "hybrid", "cplex", "gurobi"]
+    qp_order = ["cplex", "gurobi", "hybrid"]
 
     if mip is False and qp is False:
         for solver_name in lp_order:
